==> nextcloud-27.1.5.tgz: nextcloud/apps/systemtags/l10n/zh_CN.js <==
OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "系统标签 %1$s 已由系统添加",
    "Added system tag {systemtag}" : "已添加系统标签 {systemtag}",
    "Added system tag %1$s" : "已添加的系统标签 %1$s",
    "%1$s added system tag %2$s" : "%1$s 已添加的系统标签 %2$s",
    "{actor} added system tag {systemtag}" : "{actor} 已添加的系统标签 {systemtag}",
    "System tag %1$s removed by the system" : "系统标签 %1$s 已被系统移除",
    "Removed system tag {systemtag}" : "已移除的系统标签 {systemtag}",
    "Removed system tag %1$s" : "已移除的系统标签 %1$s",
    "%1$s removed system tag %2$s" : "%1$s 删除了系统标签 %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} 删除了系统标签 {systemtag}",
    "You created system tag %1$s" : "您创建了系统标签 %1$s",
    "You created system tag {systemtag}" : "您创建了系统标签 {systemtag}",
    "%1$s created system tag %2$s" : "%1$s 创建了系统标签 %2$s",
    "{actor} created system tag {systemtag}" : "{actor} 创建了系统标签 {systemtag}",
    "You deleted system tag %1$s" : "您删除了系统标签 %1$s",
    "You deleted system tag {systemtag}" : "您删除了系统标签 {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s 删除了系统标签 %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} 删除了系统标签 {systemtag}",
    "You updated system tag %2$s to %1$s" : "您已经将系统标签 %2$s 更新为 %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "您已经将系统标签 {oldsystemtag} 更新为 {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s 已经将系统标签 %3$s 更新为 %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} 已经将系统标签 {oldsystemtag} 更新为 {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "系统标签%2$s 已由系统添加到 %1$s",
    "System tag {systemtag} was added to {file} by the system" : "系统标签 {systemtag} 已由系统添加到 {file}",
    "You added system tag %2$s to %1$s" : "您为 %1$s 填加了系统标签 %2$s",
    "You added system tag {systemtag} to {file}" : "您为 {file} 添加了系统标签 {systemtag}",
    "%1$s added system tag %3$s to %2$s" : "%1$s 为 %2$s 添加了系统标签 %3$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} 为 {file} 添加了系统标签 {systemtag}",
    "System tag %2$s was removed from %1$s by the system" : "系统标签 %2$s 已被系统从 %1$s 移除",
    "System tag {systemtag} was removed from {file} by the system" : "系统标签 {systemtag} 已被系统从 {file} 移除",
    "You removed system tag %2$s from %1$s" : "您从 %1$s 移除了系统标签 %2$s",
    "You removed system tag {systemtag} from {file}" : "您从 {file} 移除了系统标签 {systemtag}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s 从 %2$s 移除了系统标签 %3$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} 从 {file} 中移除了系统标签 {systemtag}",
    "%s (restricted)" : "%s（受限）",
    "%s (invisible)" : "%s（不可见）",
    "<strong>System tags</strong> for a file have been modified" : "已更改的文件的<strong>系统标签</strong> ",
    "Tags" : "标签",
    "Collaborative tags" : "协作标签",
    "Collaborative tagging functionality which shares tags among users." : "协作标签功能在用户间共享标签。",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "协作标签功能在用户间共享标签。适合团队使用。\n\n\t（如果您是一个多租户安装实例的提供者，建议在标签共享时禁用此应用）",
    "Create" : "创建",
    "Update" : "更新",
    "Delete" : "删除",
    "Reset" : "重置",
    "Loading …" : "正在加载 …",
    "Public" : "公开",
    "Restricted" : "受限",
    "Invisible" : "不可见",
    "Failed to load tags" : "加载标签失败",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "协作标签可供所有用户使用。受限制的标签对用户可见，但不能由他们分配。不可见标签供内部使用，因为用户无法查看或分配它们。",
    "This file has the tag {tag}" : "这个文件有 {tag} 标签",
    "This file has the tags {firstTags} and {lastTag}" : "这个文件有 {firstTags} 和 {lastTag} 标签",
    "No tags found" : "标签未找到",
    "No files in here" : "无文件",
    "No entries found in this folder" : "此文件夹中无项目",
    "Name" : "名称",
    "Size" : "大小",
    "Modified" : "修改日期",
    "Tag name is empty" : "标签名为空",
    "Select tag …" : "选择标签...",
    "Tagged files" : "标签文件",
    "Select tags to filter by" : "选择标签来筛选",
    "Please select tags to filter by" : "请选择标签来筛选",
    "No files found for the selected tags" : "该标签下没有任何文件",
    "Create a new tag" : "创建新标签"
},
"nplurals=1; plural=0;");

==> nextcloud-27.1.11.tgz: nextcloud/apps/systemtags/l10n/zh_CN.js <==
OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "系统标签 %1$s 已由系统添加",
    "Added system tag {systemtag}" : "已添加系统标签 {systemtag}",
    "Added system tag %1$s" : "已添加的系统标签 %1$s",
    "%1$s added system tag %2$s" : "%1$s 已添加的系统标签 %2$s",
    "{actor} added system tag {systemtag}" : "{actor} 已添加的系统标签 {systemtag}",
    "System tag %1$s removed by the system" : "系统标签 %1$s 已被系统移除",
    "Removed system tag {systemtag}" : "已移除的系统标签 {systemtag}",
    "Removed system tag %1$s" : "已移除的系统标签 %1$s",
    "%1$s removed system tag %2$s" : "%1$s 删除了系统标签 %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} 删除了系统标签 {systemtag}",
    "You created system tag %1$s" : "您创建了系统标签 %1$s",
    "You created system tag {systemtag}" : "您创建了系统标签 {systemtag}",
    "%1$s created system tag %2$s" : "%1$s 创建了系统标签 %2$s",
    "{actor} created system tag {systemtag}" : "{actor} 创建了系统标签 {systemtag}",
    "You deleted system tag %1$s" : "您删除了系统标签 %1$s",
    "You deleted system tag {systemtag}" : "您删除了系统标签 {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s 删除了系统标签 %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} 删除了系统标签 {systemtag}",
    "You updated system tag %2$s to %1$s" : "您已经将系统标签 %2$s 更新为 %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "您已经将系统标签 {oldsystemtag} 更新为 {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s 已经将系统标签 %3$s 更新为 %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} 已经将系统标签 {oldsystemtag} 更新为 {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "系统标签%2$s 已由系统添加到 %1$s",
    "System tag {systemtag} was added to {file} by the system" : "系统标签 {systemtag} 已由系统添加到 {file}",
    "You added system tag %2$s to %1$s" : "您为 %1$s 填加了系统标签 %2$s",
    "You added system tag {systemtag} to {file}" : "您为 {file} 添加了系统标签 {systemtag}",
    "%1$s added system tag %3$s to %2$s" : "%1$s 为 %2$s 添加了系统标签 %3$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} 为 {file} 添加了系统标签 {systemtag}",
    "System tag %2$s was removed from %1$s by the system" : "系统标签 %2$s 已被系统从 %1$s 移除",
    "System tag {systemtag} was removed from {file} by the system" : "系统标签 {systemtag} 已被系统从 {file} 移除",
    "You removed system tag %2$s from %1$s" : "您从 %1$s 移除了系统标签 %2$s",
    "You removed system tag {systemtag} from {file}" : "您从 {file} 移除了系统标签 {systemtag}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s 从 %2$s 移除了系统标签 %3$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} 从 {file} 中移除了系统标签 {systemtag}",
    "%s (restricted)" : "%s（受限）",
    "%s (invisible)" : "%s（不可见）",
    "<strong>System tags</strong> for a file have been modified" : "已更改的文件的<strong>系统标签</strong> ",
    "Tags" : "标签",
    "All tagged %s …" : "所有标记为 %s ...",
    "tagged %s" : "标记为 %s",
    "Collaborative tags" : "协作标签",
    "Create or edit tags" : "创建或修改标签",
    "Search for a tag to edit" : "搜索标签并编辑",
    "Collaborative tags …" : "协作标签",
    "No tags to select" : "未选中任何标签",
    "Tag name" : "标签名称",
    "Tag level" : "标签层级",
    "Create" : "创建",
    "Update" : "更新",
    "Delete" : "删除",
    "Reset" : "重置",
    "Loading …" : "正在加载 …",
    "Public" : "公开",
    "Restricted" : "受限",
    "Invisible" : "不可见",
    "Created tag" : "创建标签",
    "Failed to create tag" : "创建标签失败",
    "Updated tag" : "更新标签",
    "Failed to update tag" : "更新标签失败",
    "Deleted tag" : "删除标签",
    "Failed to delete tag" : "删除标签失败",
    "Loading collaborative tags …" : "正在加载协作标签 ...",
    "Search or create collaborative tags" : "搜索或创建协作标签",
    "No tags to select, type to create a new tag" : "未选中任何标签，请输入并创建一个新标签",
    "Failed to load tags" : "加载标签失败",
    "Failed to load selected tags" : "无法加载选中标签",
    "Failed to select tag" : "无法选中该标签",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "协作标签可供所有用户使用。受限制的标签对用户可见，但不能由他们分配。不可见标签供内部使用，因为用户无法查看或分配它们。",
    "This file has the tag {tag}" : "这个文件有 {tag} 标签",
    "This file has the tags {firstTags} and {lastTag}" : "这个文件有 {firstTags} 和 {lastTag} 标签",
    "List of tags and their associated files and folders." : "标签以及其相关文件和文件夹",
    "No tags found" : "标签未找到",
    "Tags you have created will show up here." : "您创建的标签将显示在此处。",
    "Failed to load last used tags" : "无法加载上一次使用的标签",
    "Missing \"Content-Location\" header" : "缺少 “Content-Location” 标头",
    "Failed to load tags for file" : "无法加载该文件的标签",
    "Failed to set tag for file" : "无法设置该文件的标签",
    "Failed to delete tag for file" : "无法删除该文件的标签",
    "Tag name is empty" : "标签名为空",
    "Select tag …" : "选择标签...",
    "Collaborative tagging functionality which shares tags among users." : "协作标签功能在用户间共享标签。",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "协作标签功能在用户间共享标签。适合团队使用。\n\n\t（如果您是一个多租户安装实例的提供者，建议在标签共享时禁用此应用）",
    "Tagged files" : "标签文件",
    "Select tags to filter by" : "选择标签来筛选",
    "Please select tags to filter by" : "请选择标签来筛选",
    "No files found for the selected tags" : "该标签下没有任何文件",
    "Create a new tag" : "创建新标签",
    "Name" : "名称",
    "No files in here" : "无文件",
    "No entries found in this folder" : "此文件夹中无项目",
    "Size" : "大小",
    "Modified" : "修改日期"
},
"nplurals=1; plural=0;");
